pub struct CommonCommand {
pub disabled: bool,
}Expand description
Common collector settings
Fields
disabled: boolTrait Implementations
Sourceimpl Clone for CommonCommand
impl Clone for CommonCommand
Sourcefn clone(&self) -> CommonCommand
fn clone(&self) -> CommonCommand
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommonCommand
impl Debug for CommonCommand
Sourceimpl Default for CommonCommand
impl Default for CommonCommand
Sourcefn default() -> CommonCommand
fn default() -> CommonCommand
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CommonCommand
impl<'de> Deserialize<'de> for CommonCommand
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommonCommand
impl JsonSchema for CommonCommand
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommonCommand
impl RefUnwindSafe for CommonCommand
impl Send for CommonCommand
impl Sync for CommonCommand
impl Unpin for CommonCommand
impl UnwindSafe for CommonCommand